# CMS-NBI-CLIENT

CMS-NBI-CLIENT is a python package in the works, to interact with Calix Management System(CMS) NBIs(Northbound Interfaces). 


## Resources
___
## Official Calix Documentation
 - [Calix Management System (CMS) R14.1 Northbound Interface API Guide](https://paultclark.com/network/calix/Calix%20Management%20System%20(CMS)%20R14.1%20Northbound%20Interface%20API%20Guide.pdf)
 - [Calix E-Series (E7 OS R2.5) Engineering and Planning Guide](https://paultclark.com/network/calix/Calix%20E-Series%20(E7%20OS%20R2.6)%20Engineering%20and%20Planning%20Guide.pdf)
 - [Paul Clark's website contains a good amount of Calix docs](https://paultclark.com/network/calix/)

 - [FOR CURRENT CALIX DOCUMENTATION YOU WILL NEED A CALIX ACCOUNT TO GAIN ACCESS TO THEIR LIBRARY](https://www.calix.com)
## Examples
___
 --can be found in /Examples folder

## Authors
___
- [@Andrewshea](https://github.com/AndrewSheaM)


## License
___
[GPL-3.0](https://choosealicense.com/licenses/gpl-3.0/)

